# Evals API Reference

This page documents the API for working with evaluation configurations.

## Discovery Functions

::: agentci.client_config.evals.parser.discover_evaluations

::: agentci.client_config.evals.parser.parse_evaluation_config_toml

## Schema Models

### EvaluationConfig

::: agentci.client_config.evals.schema.EvaluationConfig

### EvaluationType

::: agentci.client_config.evals.schema.EvaluationType

### EvaluationTargets

::: agentci.client_config.evals.schema.EvaluationTargets

### EvaluationCase

::: agentci.client_config.evals.schema.EvaluationCase

## String Matching

### StringMatch

::: agentci.client_config.evals.schema.StringMatch

## Schema Validation

### SchemaField

::: agentci.client_config.evals.schema.SchemaField

## Threshold Models

### LatencyThreshold

::: agentci.client_config.evals.schema.LatencyThreshold

### TokenThreshold

::: agentci.client_config.evals.schema.TokenThreshold

### ScoreThreshold

::: agentci.client_config.evals.schema.ScoreThreshold

## Configuration Models

### LLMConfig

::: agentci.client_config.evals.schema.LLMConfig

### ConsistencyConfig

::: agentci.client_config.evals.schema.ConsistencyConfig

### CustomConfig

::: agentci.client_config.evals.schema.CustomConfig

### ToolCallSpec

::: agentci.client_config.evals.schema.ToolCallSpec
